#
# Makefile Template for Tessy
# Compiler: IAR ARM V5
# Debugger: IAR C-SPY Simulator
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CPU                   :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CONFIG_HEADER_FILE    :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# INITOBJDIR            :=
# INITSRCDIR            :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I 
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef


TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
IAR_ARM_SHORT   := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
CSPY_HOME       := $(shell ts_pathname -s '$(TARGET_INSTALL_PATH)')

TS_NAME         := TS_CSPY
IDE_NAME        := cspy
COMPANY_NAME    := iar
PROCESSOR_NAME  := arm

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.out

ifneq ($(INITSRCDIR),)
INITOBJDIR      := $(shell ts_pathname -s -m $(INITOBJDIR))
INITSRCDIR      := $(shell ts_pathname -s -m $(INITSRCDIR))
endif

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
  TS_BYTEORDER_OPTION := --endian=little
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION := --endian=big
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif


#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#-I$(INITSRCDIR) -D$(PART_NUMBER)
S_COMP_OPTIONS := --cpu=$(CPU) --debug --no_cse --no_unroll --no_inline --no_code_motion --no_tbaa --no_clustering \
                  --no_scheduling $(TS_BYTEORDER_OPTION) -e --fpu=None --dlib_config "$(CONFIG_HEADER)" \
                  --interwork --cpu_mode thumb -Ol \
                  -DTESSY -DTS_SLAVE -DTS_ARM -D$(TS_NAME) -DTS_HAVE_FLOAT32
S_ASM_OPTIONS  := -s+ -w+ -r --cpu Cortex-M3 --fpu None 
S_LINK_OPTIONS := --config "$(LINKER_FILE)" --semihosting --entry __iar_program_start --vfe 
S_INCLUDES     := -I$(IAR_ARM_SHORT)\INC -I$(IAR_ARM_SHORT)\INC\DLIB -I$(IAR_ARM_SHORT)\LIB\DLIB \
                  -I $(TESSY_SYS_DOS)\include\tessy\comm -I $(MODULE_PATH_DOS)

S_CC           := $(IAR_ARM_SHORT)\bin\iccarm
S_ASM          := $(IAR_ARM_SHORT)\bin\iasmarm
S_LINK         := $(IAR_ARM_SHORT)\bin\ilinkarm
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) -o $@ $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


# Don't show action lines
# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<
	
ifeq ("true","$(USE_BOARD_FILES)")
ARM_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
               $(patsubst $(INITSRCDIR)/%.s,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.s))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.s
	$(S_ASM) -o $@ $(S_ASM_OPTIONS) $<
endif



$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_OBJECTS) \
															$(ARM_OBJS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) $(S_STUB_OBJECT) \
   $(S_UC_OBJECT) $(S_SRC_OBJECTS) $(USER_LINK_OPTIONS) $(S_OBJECTS) $(ARM_OBJS)\
   -o "$@" $(S_LINK_OPTIONS)
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)


#####################################################################
#END_TARGETS
#####################################################################












